<?php
    /**
     * ReduxFramework Sample Config File
     * For full documentation, please visit: http://docs.reduxframework.com/
     */

    if ( ! class_exists( 'Redux' ) ) {
        return;
    }


    // This is your option name where all the Redux data is stored.
    $opt_name = "a13_option";


    /*
     *
     * --> Used within different fields. Simply examples. Search for ACTUAL DECLARATION for field examples
     *
     */

    $sampleHTML = '';
    if ( file_exists( dirname( __FILE__ ) . '/info-html.html' ) ) {
        Redux_Functions::initWpFilesystem();

        global $wp_filesystem;

        $sampleHTML = $wp_filesystem->get_contents( dirname( __FILE__ ) . '/info-html.html' );
    }

    // Background Patterns Reader
    $sample_patterns_path = ReduxFramework::$_dir . '../sample/patterns/';
    $sample_patterns_url  = ReduxFramework::$_url . '../sample/patterns/';
    $sample_patterns      = array();

    if ( is_dir( $sample_patterns_path ) ) {

        if ( $sample_patterns_dir = opendir( $sample_patterns_path ) ) {
            $sample_patterns = array();

            while ( ( $sample_patterns_file = readdir( $sample_patterns_dir ) ) !== false ) {

                if ( stristr( $sample_patterns_file, '.png' ) !== false || stristr( $sample_patterns_file, '.jpg' ) !== false ) {
                    $name              = explode( '.', $sample_patterns_file );
                    $name              = str_replace( '.' . end( $name ), '', $sample_patterns_file );
                    $sample_patterns[] = array(
                        'alt' => $name,
                        'img' => $sample_patterns_url . $sample_patterns_file
                    );
                }
            }
        }
    }

    /*
     *
     * --> Action hook examples
     *
     */

    // If Redux is running as a plugin, this will remove the demo notice and links
    //add_action( 'redux/loaded', 'remove_demo' );

    // Function to test the compiler hook and demo CSS output.
    // Above 10 is a priority, but 2 in necessary to include the dynamically generated CSS to be sent to the function.
    //add_filter('redux/options/' . $opt_name . '/compiler', 'compiler_action', 10, 3);

    // Change the arguments after they've been declared, but before the panel is created
    //add_filter('redux/options/' . $opt_name . '/args', 'change_arguments' );

    // Change the default value of a field after it's been set, but before it's been useds
    //add_filter('redux/options/' . $opt_name . '/defaults', 'change_defaults' );

    // Dynamically add a section. Can be also used to modify sections/fields
    //add_filter('redux/options/' . $opt_name . '/sections', 'dynamic_section');


    /**
     * ---> SET ARGUMENTS
     * All the possible arguments for Redux.
     * For full documentation on arguments, please refer to: https://github.com/ReduxFramework/ReduxFramework/wiki/Arguments
     * */

    $theme = wp_get_theme(); // For use with some settings. Not necessary.

    $args = array(
        // TYPICAL -> Change these values as you need/desire
        'opt_name'             => $opt_name,
        // This is where your data is stored in the database and also becomes your global variable name.
        'ajax_save'            => false,
        'display_name'         => $theme->get( 'Name' ),
        // Name that appears at the top of your panel
        'display_version'      => $theme->get( 'Version' ),
        // Version that appears at the top of your panel
        'menu_type'            => 'menu',
        //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
        'allow_sub_menu'       => true,
        // Show the sections below the admin menu item or not
        'menu_title'           => __( 'CeeVee options', 'redux-framework-demo' ),
        'page_title'           => __( 'CeeVee options', 'redux-framework-demo' ),
        // You will need to generate a Google API key to use this feature.
        // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
        'google_api_key'       => 'AIzaSyAX_2L_UzCDPEnAHTG7zhESRVpMPS4ssII',
        // Set it you want google fonts to update weekly. A google_api_key value is required.
        'google_update_weekly' => false,
        // Must be defined to add google fonts to the typography module
        'async_typography'     => true,
        // Use a asynchronous font on the front end or font string
        //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
        'admin_bar'            => true,
        // Show the panel pages on the admin bar
        'admin_bar_icon'       => 'dashicons-portfolio',
        // Choose an icon for the admin bar menu
        'admin_bar_priority'   => 50,
        // Choose an priority for the admin bar menu
        'global_variable'      => '',
        // Set a different name for your global variable other than the opt_name
        'dev_mode'             => false,
        // Show the time the page took to load, etc
        'update_notice'        => false,
        // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
        'customizer'           => true,
        // Enable basic customizer support
        //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
        //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field

        // OPTIONAL -> Give you extra features
        'page_priority'        => null,
        // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
        'page_parent'          => 'themes.php',
        // For a full list of options, visit: http://codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
        'page_permissions'     => 'manage_options',
        // Permissions needed to access the options panel.
        'menu_icon'            => '',
        // Specify a custom URL to an icon
        'last_tab'             => '',
        // Force your panel to always open to a specific tab (by id)
        'page_icon'            => 'icon-themes',
        // Icon displayed in the admin panel next to your menu_title
        'page_slug'            => '',
        // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
        'save_defaults'        => true,
        // On load save the defaults to DB before user clicks save or not
        'default_show'         => false,
        // If true, shows the default value next to each field that is not the default value.
        'default_mark'         => '',
        // What to print by the field's title if the value shown is default. Suggested: *
        'show_import_export'   => true,
        // Shows the Import/Export panel when not used as a field.

        // CAREFUL -> These options are for advanced use only
        'transient_time'       => 60 * MINUTE_IN_SECONDS,
        'output'               => true,
        // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
        'output_tag'           => true,
        // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
        // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

        // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
        'database'             => '',
        // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
        'system_info'          => false,
        // REMOVE

        //'compiler'             => true,

        // HINTS
        'hints'                => array(
            'icon'          => 'el el-question-sign',
            'icon_position' => 'right',
            'icon_color'    => 'lightgray',
            'icon_size'     => 'normal',
            'tip_style'     => array(
                'color'   => 'light',
                'shadow'  => true,
                'rounded' => false,
                'style'   => '',
            ),
            'tip_position'  => array(
                'my' => 'top left',
                'at' => 'bottom right',
            ),
            'tip_effect'    => array(
                'show' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'mouseover',
                ),
                'hide' => array(
                    'effect'   => 'slide',
                    'duration' => '500',
                    'event'    => 'click mouseleave',
                ),
            ),
        )
    );

    // ADMIN BAR LINKS -> Setup custom links in the admin bar menu as external items.
/*
    $args['admin_bar_links'][] = array(
        'id'    => 'redux-docs',
        'href'  => 'http://docs.reduxframework.com/',
        'title' => __( 'Documentation', 'redux-framework-demo' ),
    );

    $args['admin_bar_links'][] = array(
        //'id'    => 'redux-support',
        'href'  => 'https://github.com/ReduxFramework/redux-framework/issues',
        'title' => __( 'Support', 'redux-framework-demo' ),
    );

    $args['admin_bar_links'][] = array(
        'id'    => 'redux-extensions',
        'href'  => 'reduxframework.com/extensions',
        'title' => __( 'Extensions', 'redux-framework-demo' ),
    );
*/
    // SOCIAL ICONS -> Setup custom links in the footer for quick links in your panel footer icons.
    $args['share_icons'][] = array(
        'url'   => 'https://github.com/ReduxFramework/ReduxFramework',
        'title' => 'Visit us on GitHub',
        'icon'  => 'el el-github'
        //'img'   => '', // You can use icon OR img. IMG needs to be a full URL.
    );
    $args['share_icons'][] = array(
        'url'   => 'https://www.facebook.com/pages/Redux-Framework/243141545850368',
        'title' => 'Like us on Facebook',
        'icon'  => 'el el-facebook'
    );
    $args['share_icons'][] = array(
        'url'   => 'http://twitter.com/reduxframework',
        'title' => 'Follow us on Twitter',
        'icon'  => 'el el-twitter'
    );
    $args['share_icons'][] = array(
        'url'   => 'http://www.linkedin.com/company/redux-framework',
        'title' => 'Find us on LinkedIn',
        'icon'  => 'el el-linkedin'
    );

    // Panel Intro text -> before the form
    if ( ! isset( $args['global_variable'] ) || $args['global_variable'] !== false ) {
        if ( ! empty( $args['global_variable'] ) ) {
            $v = $args['global_variable'];
        } else {
            $v = str_replace( '-', '_', $args['opt_name'] );
        }
        $args['intro_text'] = sprintf( __( '<p>Did you know that Redux sets a global variable for you? To access any of your saved options from within your code you can use your global variable: <strong>$%1$s</strong></p>', 'redux-framework-demo' ), $v );
    } else {
        $args['intro_text'] = __( '<p>This text is displayed above the options panel. It isn\'t required, but more info is always better! The intro_text field accepts all HTML.</p>', 'redux-framework-demo' );
    }

    // Add content after the form.
    $args['footer_text'] = __( '<p>This text is displayed below the options panel. It isn\'t required, but more info is always better! The footer_text field accepts all HTML.</p>', 'redux-framework-demo' );

    Redux::setArgs( $opt_name, $args );

    /*
     * ---> END ARGUMENTS
     */


    /*
     * ---> START HELP TABS
     */

    $tabs = array(
        array(
            'id'      => 'redux-help-tab-1',
            'title'   => __( 'Theme Information 1', 'redux-framework-demo' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo' )
        ),
        array(
            'id'      => 'redux-help-tab-2',
            'title'   => __( 'Theme Information 2', 'redux-framework-demo' ),
            'content' => __( '<p>This is the tab content, HTML is allowed.</p>', 'redux-framework-demo' )
        )
    );
    Redux::setHelpTab( $opt_name, $tabs );

    // Set the help sidebar
    $content = __( '<p>This is the sidebar content, HTML is allowed.</p>', 'redux-framework-demo' );
    Redux::setHelpSidebar( $opt_name, $content );


    /*
     * <--- END HELP TABS
     */


    /*
     *
     * ---> START SECTIONS
     *
     */

    /*

        As of Redux 3.5+, there is an extensive API. This API can be used in a mix/match mode allowing for


     */

    // -> START Basic Fields
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Layout' ),
		'icon' => 'el-icon-eye-open',
        'heading' => '',
        'desc'    => ''
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'General' ),
		'icon' => 'el-icon-eye-open',
        'subsection' =>true,
        'desc'    => '',
        'fields'  => array(
            
            array(
				'id'            => 'layout_favicon',
				'type'          => 'media', 
				'title'         => __be( 'Favicon' ),
				'desc'          => __be( 'Enter an URL or upload an image for favicon. It will appear in adress bar or on tab in browser. Image should be square (16x16px or 32x32px). Paste the full URL (include http://).' ),
				'default'  => array(
                    'url'=>'http://ceevee.apollo13.eu/wp-content/uploads/2015/03/favicon1.gif',
                    'width' => '16',
                    'height' => '16'
                ),
			),
            array(
				'id'            => 'layout_background_image',
				'type'          => 'media', 
				'title'         => __be( 'Custom image for background' ),
                'subtitle'      => '',
				'desc'          => '',
                'default'  => array(
                    'url'=>'http://ceevee.apollo13.eu/wp-content/uploads/2015/03/BG12.jpg',
                    'width' => '1980',
                    'height' => '1311'
                ),
			),
            array(
				'id'            => 'layout_background_image_fit',
				'type'          => 'select',
				'options'       => array(
                                        'cover'     => __be( 'Cover' ),
                                        'contain'   => __be( 'Contain' ),
                                        'fitV'      => __be( 'Fit Vertically' ),
                                        'fitH'      => __be( 'Fit Horizontally' ),
                                        'center'    => __be( 'Just center' ),
                                        'repeat'    => __be( 'Repeat' ),
                                    ),
                'default'       => 'cover',
                'placeholder'   => __be( 'Pick one' ), 
				'title'         => __be( 'How to fit background image' ), 
				'subtitle'      => "",
				'desc'          => "",
			),
            array(
				'id'            => 'layout_background_image_attachment',
				'type'          => 'button_set',
				'title'         => __be( 'Background attachment' ),
				'subtitle'      => "",
				'desc'          => "",
				'options'       => array( 'fixed' => __be( 'fixed' ), 'scroll' => __be( 'scroll' ) ),//Must provide key => value pairs for radio options
				'default'       => 'fixed',
			),
            array(
				'id'            => 'layout_background_color',
				'type'          => 'color', 
				'title'         => __be( 'Custom background color' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#222222',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_mousewheel_speed',
				'type'          => 'slider', 
				'title'         => __be( 'Set the mouse wheel scroll speed' ),
                'subtitle'      => '',
				'desc'          => '',
				"default" 		=> '80',
				"min" 		    => "10",
                "step"          => "1",
				"max" 		    => "200",  
			),  
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Logo' ),
		'icon' => 'el-icon-eye-open',
        'subsection' =>true,
        'desc'    => '',
        'fields'  => array(
            array(
				'id'            => 'layout_logo_type',
				'type'          => 'button_set',
				'title'         => __be( 'Logo type' ),
				'subtitle'      => "",
				'desc'          => "",
				'options'       => array( 'image' => __be( 'Image' ), 'text' => __be( 'Text' ), 'image_text' => __be( 'Image with text' ) ),//Must provide key => value pairs for radio options
				'default'       => 'image',
			),
            array(
				'id'            => 'layout_logo_image1',
				'type'          => 'media', 
				'title'         => __be( 'Logo image' ),
                'required'      => array( 'layout_logo_type', 'contains', 'image' ),
				'desc'          => '',
                'default'  => array(
                    'url'=>'http://ceevee.apollo13.eu/wp-content/uploads/2015/03/logo.png',
                    'width' => '345',
                    'height' => '79'
                ),
				
			),
            array(
				'id'            => 'layout_logo_retina_image1',
				'type'          => 'media', 
				'title'         => __be( 'Logo image' ),
                'subtitle'      => __be( 'for retina and other HDPI devices' ),
                'required'      => array( 'layout_logo_type', 'contains', 'image' ),
				'desc'          => '',
                'default'  => array(
                    'url'=>'http://ceevee.apollo13.eu/wp-content/uploads/2015/03/logo@2x.png',
                    'width' => '518',
                    'height' => '119'
                ),
				
			),
            array(
				'id'            => 'layout_logo_image1_top',
				'type'          => 'slider', 
				'title'         => __be( 'Logo image top margin' ),
                'subtitle'      => __be( 'Only for header shield, in pixels' ),
                'required'      => array( 'layout_logo_type', 'contains', 'image' ),
				'desc'          => '',
				"default" 		=> '30',
				"min" 		    => "0",
                "step"          => "1",
				"max" 		    => "150",  
			),  
            array(
				'id'            => 'layout_logo_text',
				'type'          => 'text',
				'title'         => __be( 'Text' ),
                "default"       => 'CeeVee',
                'required'      => array( 'layout_logo_type', 'contains', 'text' ),
				'subtitle'      => "",
				'desc'          => "",
			),
            array(
				'id'            => 'layout_logo_text_color',
				'type'          => 'color', 
				'title'         => __be( 'Color' ),
                'required'      => array( 'layout_logo_type', 'contains', 'text' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#FFFFFF',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_logo_text_size',
				'type'          => 'slider', 
				'title'         => __be( 'Text size' ),
                'subtitle'      => __be( 'in pixels' ),
                'required'      => array( 'layout_logo_type', 'contains', 'text' ),
				'desc'          => '',
				"default" 		=> '24',
				"min" 		    => "10",
                "step"          => "1",
				"max" 		    => "30",  
			), 
            array(
				'id'            => 'layout_logo_text_weight',
				'type'          => 'button_set', 
				'title'         => __be( 'Text weight' ),
                'desc'          => "",
				'subtitle'      => "",
                'required'      => array( 'layout_logo_type', '=', 'text' ),
				'options'       => array( 'normal' => __be( 'Normal' ), 'bold' => __be( 'Bold' ) ),//Must provide key => value pairs for radio options
				'default'       => 'bold'
			),	
            array(
				'id'            => 'layout_logo_text_transform',
				'type'          => 'button_set', 
				'title'         => __be( 'Text transform' ),
                'desc'          => "",
				'subtitle'      => "",
                'required'      => array( 'layout_logo_type', '=', 'text' ),
				'options'       => array( 'lowercase' => __be( 'Lowercase' ), 'none' => __be( 'None' ), 'uppercase' => __be( 'Uppercase' ) ),//Must provide key => value pairs for radio options
				'default'       => 'uppercase'
			),	
            array(
				'id'            => 'layout_logo_spacing',
				'type'          => 'spacing',
				'mode'          => 'padding', // absolute, padding, margin, defaults to padding
				
				'units'         => 'px', // You can specify a unit value. Possible: px, em, %
				
				'title'         => __be( 'Logo padding' ),
				'subtitle'      => "",
				'desc'          => "",
                'required'      => array( 'layout_logo_type', 'contains', 'text' ),
				'default'       => array('padding-top' => '0px','padding-right'=>'0px', 'padding-bottom' => '0px', 'padding-left'=>'0px' ),
                'output'        => array( '#logo > div' )
			),	
           
            
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Preloader' ),
		'icon' => 'el-icon-eye-open',
        'subsection' =>true,
        'desc'    => '',
        'fields'  => array(
            
            
            array(
				'id'            => 'preloader_enable',
				'type'          => 'switch', 
				'title'         => __be( 'Preloader' ),
                'desc'          => '',
				'subtitle'      => "",
				"default"       => 1,
				'on'            => __be( 'Enable' ),
                'off'           => __be( 'Disable' ),
			),	
            array(
				'id'            => 'layout_preloader_overlay_color',
				'type'          => 'color_rgba', 
				'title'         => __be( 'Background color' ),
                'desc'          => __be( 'Can have transparecy, so the background image could be visible' ),
				'subtitle'      => "",
				'default'  => array(
                    'color' => '#000000',
                    'alpha' => '0.0'
                ),
				'validate'      => 'colorrgba',
                'required'      => array( 'preloader_enable', '=', '1' ),
			),
            array(
				'id'            => 'layout_preloader_icon1',
				'type'          => 'media', 
				'title'         => __be( 'Preloader icon 1' ),
				'desc'          => '',
                
                'required'      => array( 'preloader_enable', '=', '1' ),
                
			),
            array(
				'id'            => 'layout_preloader_icon2',
				'type'          => 'media', 
				'title'         => __be( 'Preloader icon 2' ),
                'subtitle'      => '',
				'desc'          => '',
                
                'required'      => array( 'preloader_enable', '=', '1' ),
			),
            array(
				'id'            => 'layout_preloader_stroke_color1',
				'type'          => 'color', 
				'title'         => __be( 'Primary color of preloader circle' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#3f3f3f',
				'validate'      => 'color',
                'required'      => array( 'preloader_enable', '=', '1' ),
			),
            array(
				'id'            => 'layout_preloader_stroke_color2',
				'type'          => 'color', 
				'title'         => __be( 'Secondary color of preloader circle' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#e2e2e2',
				'validate'      => 'color',
                'required'      => array( 'preloader_enable', '=', '1' ),
			),
            array(
				'id'            => 'layout_preloader_circle_radius',
				'type'          => 'slider', 
				'title'         => __be( 'Spinning circle radius' ),
                'subtitle'      => '',
                'required'      => array( 'preloader_enable', '=', '1' ),
				'desc'          => '',
				"default" 		=> '50',
				"min" 		    => "50",
                "step"          => "1",
				"max" 		    => "200",  
			),
            array(
				'id'            => 'layout_preloader_circle_width',
				'type'          => 'slider', 
				'title'         => __be( 'Spinning circle width' ),
                'subtitle'      => '',
                'required'      => array( 'preloader_enable', '=', '1' ),
				'desc'          => '',
				"default" 		=> '6',
				"min" 		    => "1",
                "step"          => "1",
				"max" 		    => "50",  
			),
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Header' ),
		'icon' => 'el-icon-eye-open',
        'subsection' =>true,
        'desc'    => '',
        'fields'  => array(
            
            
            array(
				'id'            => 'layout_header_social',
				'type'          => 'switch', 
				'title'         => __be( 'Display social icos in header?' ),
                'desc'          => "",
				'subtitle'      => "",
				"default"       => 1,
				'on'            => __be( 'Yes' ),
                'off'           => __be( 'No' ),
			),
            
            
            
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Buttons and links' ),
		'icon' => 'el-icon-eye-open',
        'subsection' =>true,
        'desc'    => '',
        'fields'  => array(
            array(
				'id'            => 'layout_btn_font_color',
				'type'          => 'color', 
				'title'         => __be( "Button's font color" ),
                'desc'          => __be( "Will be used as background color of hover action, and as a color for button's border" ),
				'subtitle'      => "",
				'default'       => '#ffffff',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_btn_bg_color',
				'type'          => 'color', 
				'title'         => __be( "Button's background color" ),
                'desc'          => __be( "Will be used as font color of hover action" ),
				'subtitle'      => "",
				'default'       => '#4f4f4f',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_btn_font_size',
				'type'          => 'slider', 
				'title'         => __be( "Button's font size" ),
                'subtitle'      => "",
				'desc'          => "",
				"default" 		=> "12",
				"min" 		    => "10",
                "step"          => "1",
				"max" 		    => "40",  
			), 
            array(
				'id'            => 'layout_btn_spacing',
				'type'          => 'spacing',
				'mode'          => 'padding', // absolute, padding, margin, defaults to padding
				//'units'         => 'px', // You can specify a unit value. Possible: px, em, %
				
				'title'         => __be( "Button's paddings" ),
				'subtitle'      => "",
				'desc'          => "",
				'default'       => array('padding-top' => '10px', 'padding-bottom' => '10px', 'padding-left'=>'20px', 'padding-right'=>'20px' )
			),	
            array(
				'id'            => 'layout_btn_transform',
				'type'          => 'button_set', 
				'title'         => __be( "Button's text transform" ),
                'desc'          => "",
				'subtitle'      => "",
				'options'       => array( 'lowercase' => __be( 'Lowercase' ), 'none' => __be( 'None' ), 'uppercase' => __be( 'Uppercase' ) ),//Must provide key => value pairs for radio options
				'default'       => 'uppercase'
			),	
            array(
				'id'            => 'layout_btn_text_weight',
				'type'          => 'button_set', 
				'title'         => __be( "Button's font weight" ),
                'desc'          => "",
				'subtitle'      => "",
				'options'       => array( 'normal' => __be( 'Normal' ), 'bold' => __be( 'Bold' ) ),//Must provide key => value pairs for radio options
				'default'       => 'bold'
			),
            array(
				'id'            => 'layout_anchor_color',
				'type'          => 'color', 
				'title'         => __be( 'Links color' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#5e5e5e',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_anchor_hover_color',
				'type'          => 'color', 
				'title'         => __be( 'Links color on-hover' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#222222',
				'validate'      => 'color',
			),
           
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Headings' ),
		'icon' => 'el-icon-eye-open',
        'subsection' =>true,
        'desc'    => '',
        'fields'  => array(
            array(
				'id'            => 'layout_h1_font_size',
				'type'          => 'slider', 
				'title'         => __be( 'H1 font size' ),
                'subtitle'      => __be( 'in pixels' ),
				'desc'          => '',
				"default" 		=> '50',
				"min" 		    => "10",
                "step"          => "1",
				"max" 		    => "50",  
			), 
            array(
				'id'            => 'layout_h2_font_size',
				'type'          => 'slider', 
				'title'         => __be( 'H2 font size' ),
                'subtitle'      => __be( 'in pixels' ),
				'desc'          => '',
				"default" 		=> '40',
				"min" 		    => "10",
                "step"          => "1",
				"max" 		    => "50",  
			), 
            array(
				'id'            => 'layout_h3_font_size',
				'type'          => 'slider', 
				'title'         => __be( 'H3 font size' ),
                'subtitle'      => __be( 'in pixels' ),
				'desc'          => '',
				"default" 		=> '30',
				"min" 		    => "10",
                "step"          => "1",
				"max" 		    => "50",  
			), 
            array(
				'id'            => 'layout_h4_font_size',
				'type'          => 'slider', 
				'title'         => __be( 'H4 font size' ),
                'subtitle'      => __be( 'in pixels' ),
				'desc'          => '',
				"default" 		=> '26',
				"min" 		    => "10",
                "step"          => "1",
				"max" 		    => "50",  
			), 
            array(
				'id'            => 'layout_h5_font_size',
				'type'          => 'slider', 
				'title'         => __be( 'H5 font size' ),
                'subtitle'      => __be( 'in pixels' ),
				'desc'          => '',
				"default" 		=> '20',
				"min" 		    => "10",
                "step"          => "1",
				"max" 		    => "50",  
			), 
            array(
				'id'            => 'layout_h6_font_size',
				'type'          => 'slider', 
				'title'         => __be( 'H6 font size' ),
                'subtitle'      => __be( 'in pixels' ),
				'desc'          => '',
				"default" 		=> '12',
				"min" 		    => "10",
                "step"          => "1",
				"max" 		    => "50",  
			), 
           
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Navigation Menu' ),
		'icon' => 'el-icon-eye-open',
        'subsection' =>true,
        'desc'    => '',
        'fields'  => array(
            array(
				'id'            => 'layout_header_text_weight',
				'type'          => 'button_set', 
				'title'         => __be( 'Text weight for navigation menu' ),
                'desc'          => "",
				'subtitle'      => "",
				'options'       => array( 'normal' => __be( 'Normal' ), 'bold' => __be( 'Bold' ) ),//Must provide key => value pairs for radio options
				'default'       => 'bold'
			),
            array(
				'id'            => 'layout_menu_switch_color',
				'type'          => 'color_rgba', 
				'title'         => __be( 'Font color of the navigation menu' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'  => array(
                    'color' => '#ffffff',
                    'alpha' => '0.4'
                ),
				'validate'      => 'colorrgba',
			),
            array(
				'id'            => 'layout_menu_hover_switch_color',
				'type'          => 'color_rgba', 
				'title'         => __be( 'Font color of the navigation menu' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'  => array(
                    'color' => '#ffffff',
                    'alpha' => '1'
                ),
				'validate'      => 'colorrgba',
			),
            array(
				'id'            => 'layout_header_text_transform',
				'type'          => 'button_set', 
				'title'         => __be( 'Text transform for navigation menu' ),
                'desc'          => "",
				'subtitle'      => "",
				'options'       => array( 'lowercase' => __be( 'Lowercase' ), 'none' => __be( 'None' ), 'uppercase' => __be( 'Uppercase' ) ),//Must provide key => value pairs for radio options
				'default'       => 'uppercase'
			),
            array(
				'id'            => 'layout_menu_font_size',
				'type'          => 'slider', 
				'title'         => __be( 'Font size for menu items' ),
                'subtitle'      => __be( 'in pixels' ),
				'desc'          => '',
				"default" 		=> '35',
				"min" 		    => "10",
                "step"          => "1",
				"max" 		    => "60",  
			),             
            array(
				'id'            => 'layout_header_font_color',
				'type'          => 'color', 
				'title'         => __be( 'Font color of the navigation menu' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#666666',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_header_action_hover_text_color',
				'type'          => 'color', 
				'title'         => __be( 'Text color of hover/active of navigation menu items' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#ffffff',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_header_bg_color',
				'type'          => 'color_rgba', 
				'title'         => __be( 'Background color of the navigation menu' ),
                'desc'          => '',
				'subtitle'      => "",
				'default'  => array(
                    'color' => '#010101',
                    'alpha' => '1'
                ),
				'validate'      => 'colorrgba',
			),
            
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Footer' ),
		'icon' => 'el-icon-eye-open',
        'subsection' =>true,
        'desc'    => '',
        'fields'  => array(
            	
          
            array(
				'id'            => 'layout_footer_font_size',
				'type'          => 'slider', 
				'title'         => __be( 'Font size' ),
                'subtitle'      => __be( 'in pixels' ),
				'desc'          => '',
				"default" 		=> '10',
				"min" 		    => "10",
                "step"          => "1",
				"max" 		    => "30",  
			),
            array(
				'id'            => 'layout_footer_color',
				'type'          => 'color', 
				'title'         => __be( 'Font color' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#777777',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_footer_link_color',
				'type'          => 'color', 
				'title'         => __be( 'Link color' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#c4c4c4',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_footer_link_hover_color',
				'type'          => 'color', 
				'title'         => __be( 'Link color hover' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#f9f9f9',
				'validate'      => 'color',
			),    
            array(
				'id'            => 'layout_copyright_text',
				'type'          => 'textarea', 
				'title'         => __be( 'Copyright text' ),
                'desc'          => __be( 'You can put a valid HTML string here.' ),
                "default"       => __be('<div style="text-transform:uppercase;"><a href=""><span class="fa fa-external-link-square"></span> Download My resume</a>, P: +1 714-236-2369, <a href=""><span class="fa fa-envelope-o"></span> james@anderson.com</a>
James M. Anderson © 2015 All rights reserved.</div>'),
				'subtitle'      => "",
			), 
           
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Typography' ),
		'icon' => 'el-icon-eye-open',
        'subsection' =>true,
        'fields' => array(


            array(
				'id'            => 'layout_font_group1',
				'type'          => 'typography',
				'title'         => __be( 'Font settings for headers, buttons' ),
				'subtitle'      => "",
				'google'        => true,
                'letter-spacing'=> true,
                'font-size'     => false,
				'default'       => array(
					'color'        => '#222222',
					'sunsets'      => 'latin',
                    'line-height'  => '30px',
					'font-family'  => 'Raleway',
                    'letter-spacing' => '0',
					'font-weight'  => '700',
                    'google'       => true,
				),
			),
            array(
				'id'            => 'layout_font_group3',
				'type'          => 'typography',
				'title'         => __be( 'Second font family to use in headings' ),
				'subtitle'      => "",
				'google'        => true,
                'font-size'     => false,
                'text-align'    => false,
                'color'         => false,
                'letter-spacing'=> true,
				'default'       => array(
					'color'        => '#545454',
                    'line-height'  => '24px',
                    'letter-spacing' => '0',
					'font-family'  => 'Herr Von Muellerhoff',
					'font-weight'  => '400',
                    'google'       => true,
				),
			),
            
            array(
				'id'            => 'layout_font_group3_diff',
				'type'          => 'slider', 
				'title'         => __be( 'Font size difference for second font family' ),
                'subtitle'      => __be( 'in pixels' ),
				'desc'          => __be( 'Font size for headings that use second font family will be increased or decreased by this value.' ),
				"default" 		=> '0',
				"min" 		    => "-30",
                "step"          => "1",
				"max" 		    => "30",  
			),            
            array(
				'id'            => 'layout_font_group2',
				'type'          => 'typography',
				'title'         => __be( 'Font settings for content' ),
				'subtitle'      => "",
				'google'        => true,
                'letter-spacing'=> true,
				'default'       => array(
					'color'        => '#888888',
					'font-size'    => '13px',
                    'line-height'  => '22px',
					'font-family'  => 'Raleway',
                    'letter-spacing' => '0',
					'font-weight'  => '400',
                    'google'       => true,
				),
			),
            
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Responsive settings' ),
		'icon' => 'el-icon-eye-open',
        'subsection' =>true,
        'fields' => array(
            array(
				'id'            => 'layout_threshold_for_tiles',
				'type'          => 'slider', 
				'title'         => __be( 'Screen width below which tiles are extremaly narrow in open state' ),
                'subtitle'      => __be( 'in pixels' ),
				'desc'          => '',
				"default" 		=> '400',
				"min" 		    => "200",
                "step"          => "1",
				"max" 		    => "900",  
			),   
            array(
				'id'            => 'layout_threshold_w_mobile',
				'type'          => 'slider', 
				'title'         => __be( 'Screen width below which slider goes into mobile mode' ),
                'subtitle'      => __be( 'in pixels' ),
				'desc'          => '',
				"default" 		=> '800',
				"min" 		    => "200",
                "step"          => "1",
				"max" 		    => "2500",  
			),   
            array(
				'id'            => 'layout_threshold_h_mobile',
				'type'          => 'slider', 
				'title'         => __be( 'Screen height below which slider goes into mobile mode' ),
                'subtitle'      => __be( 'in pixels' ),
				'desc'          => '',
				"default" 		=> '520',
				"min" 		    => "150",
                "step"          => "1",
				"max" 		    => "2500",  
			),            
            
            
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Blog' ),
		'icon' => 'el-icon-home',
        'heading' => '',
        'desc'    => '',
        'fields'  => array(
            
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Blog page' ),
		'icon' => 'el-icon-home',
        'subsection' => true,
        'fields' => array(
           
            array(
				'id'            => 'blog_posts_excerpt_mode',
				'type'          => 'button_set', 
				'title'         => __be( 'Type of post excerpts' ),
                'desc'          => __be( "In Manual mode excerpts are used only if you add more tag (<!--more-->). In Automatic mode if you won't provide more tag or explicit excerpt, content of post will be cut automaticly. This setting will be applied to the blog list, archive list and search results." ),
				'subtitle'      => "",
                'options'       => array( 'auto' => __be( 'Automatic' ), 'manual' => __be( 'Manual' ) ),//Must provide key => value pairs for radio options
				'default'       => 'manual'
			),
            array(
				'id'            => 'blog_sidebar',
				'type'          => 'button_set', 
				'title'         => __be( 'Blog sidebar' ),
                'desc'          => "",
				'subtitle'      => "",
                'options'       => array( 'left-sidebar' => __be( 'Left' ), 'right-sidebar' => __be( 'Right' ), 'off' => __be( 'Off' ) ),//Must provide key => value pairs for radio options
				'default'       => 'left-sidebar'
			),
            array(
				'id'            => 'blog_rss_icon',
				'type'          => 'switch', 
				'title'         => __be( 'RSS icon' ),
                'desc'          => "",
				'subtitle'      => "",
				"default"       => 0,
				'on'            => __be( 'On' ),
                'off'           => __be( 'Off' ),
			),
            array(
				'id'            => 'blog_post_media',
				'type'          => 'switch', 
				'title'         => __be( 'Display media' ),
                'desc'          => __be( 'By disabling this setting you will hide any kind of media, you will get only post excerpt.' ),
				'subtitle'      => "",
				"default"       => 1,
				'on'            => __be( 'On' ),
                'off'           => __be( 'Off' ),
			),
            array(
				'id'            => 'blog_meta_date',
				'type'          => 'switch', 
				'title'         => __be( 'Post meta: Date' ),
                'desc'          => "",
				'subtitle'      => "",
				"default"       => 1,
				'on'            => __be( 'On' ),
                'off'           => __be( 'Off' ),
			),
            array(
				'id'            => 'blog_meta_author',
				'type'          => 'switch', 
				'title'         => __be( 'Post meta: Author' ),
                'desc'          => "",
				'subtitle'      => "",
				"default"       => 1,
				'on'            => __be( 'On' ),
                'off'           => __be( 'Off' ),
			),
            array(
				'id'            => 'blog_meta_comments_number',
				'type'          => 'switch', 
				'title'         => __be( 'Post meta: Comments number' ),
                'desc'          => "",
				'subtitle'      => "",
				"default"       => 1,
				'on'            => __be( 'On' ),
                'off'           => __be( 'Off' ),
			),
            array(
				'id'            => 'blog_meta_categories',
				'type'          => 'switch', 
				'title'         => __be( 'Post meta: Categories' ),
                'desc'          => "",
				'subtitle'      => "",
				"default"       => 1,
				'on'            => __be( 'On' ),
                'off'           => __be( 'Off' ),
			),
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Single post' ),
		'icon' => 'el-icon-home',
        'subsection' => true,
        'fields' => array(
            
            array(
				'id'            => 'post_sidebar',
				'type'          => 'button_set', 
				'title'         => __be( 'Post sidebar' ),
                'desc'          => "",
				'subtitle'      => "",
                'options'       => array( 'left-sidebar' => __be( 'Left' ), 'right-sidebar' => __be( 'Right' ), 'off' => __be( 'Off' ) ),//Must provide key => value pairs for radio options
				'default'       => 'right-sidebar'
			),
            array(
				'id'            => 'post_media',
				'type'          => 'switch', 
				'title'         => __be( 'Display media in post' ),
                'desc'          => "",
				'subtitle'      => "",
				"default"       => 1,
				'on'            => __be( 'On' ),
                'off'           => __be( 'Off' ),
			),
            array(
				'id'            => 'post_meta_date',
				'type'          => 'switch', 
				'title'         => __be( 'Post meta: Date' ),
                'desc'          => "",
				'subtitle'      => "",
				"default"       => 1,
				'on'            => __be( 'On' ),
                'off'           => __be( 'Off' ),
			),
            array(
				'id'            => 'post_meta_author',
				'type'          => 'switch', 
				'title'         => __be( 'Post meta: Author' ),
                'desc'          => "",
				'subtitle'      => "",
				"default"       => 1,
				'on'            => __be( 'On' ),
                'off'           => __be( 'Off' ),
			),
            array(
				'id'            => 'post_meta_comments_number',
				'type'          => 'switch', 
				'title'         => __be( 'Post meta: Comments number' ),
                'desc'          => "",
				'subtitle'      => "",
				"default"       => 1,
				'on'            => __be( 'On' ),
                'off'           => __be( 'Off' ),
			),
            array(
				'id'            => 'post_meta_categories',
				'type'          => 'switch', 
				'title'         => __be( 'Post meta: Categories' ),
                'desc'          => "",
				'subtitle'      => "",
				"default"       => 1,
				'on'            => __be( 'On' ),
                'off'           => __be( 'Off' ),
			),
            array(
				'id'            => 'post_meta_tags',
				'type'          => 'switch', 
				'title'         => __be( 'Post meta: Tags' ),
                'desc'          => "",
				'subtitle'      => "",
				"default"       => 1,
				'on'            => __be( 'On' ),
                'off'           => __be( 'Off' ),
			),
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Social settings' ),
		'icon' => 'el-icon-user',
        'fields' => array(
            array(
				'id'            => 'social-info-contact-form',
				'type'          => 'info',
                'class'         => 'to-accordion',
				'desc'          => __be( 'Contact form' ),
                'icon'          => '',
			),
            array(
				'id'            => 'layout_social_form_font_color',
				'type'          => 'color', 
				'title'         => __be( 'Font color of contact form input' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#999999',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_social_form_font_hover_color',
				'type'          => 'color', 
				'title'         => __be( 'Font color of contact form input whene hovered' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#666666',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_social_form_bg_color',
				'type'          => 'color', 
				'title'         => __be( 'Background color of contact form input' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#f2f2f2',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_social_form_bg_hover_color',
				'type'          => 'color', 
				'title'         => __be( 'Background color of contact form input whene hovered' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#ffffff',
				'validate'      => 'color',
			),
            
            array(
				'id'            => 'contact_form_verbose_mode',
				'type'          => 'switch', 
				'title'         => __be( 'Verbose mode' ),
                'desc'          => __be( 'You can get configurable validation messages in contact form by switching this setting on.' ),
				'subtitle'      => "",
				"default"       => 0,
				'on'            => __be( 'Enable' ),
                'off'           => __be( 'Disable' ),
			),	
            array(
				'id'            => 'social-info-services',
				'type'          => 'info',
                'class'         => 'to-accordion',
				'desc'          => __be( 'Colors' ),
                'icon'          => '',
			),
            array(
				'id'            => 'layout_social_ribbon_color',
				'type'          => 'color', 
				'title'         => __be( 'Ribbon color' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#696969',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_social_stitch_color',
				'type'          => 'color', 
				'title'         => __be( 'Stitch color' ),
                
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#545454',
				'validate'      => 'color',
			),
            array(
				'id'            => 'layout_social_icon_color',
				'type'          => 'color', 
				'title'         => __be( 'Icon color' ),
                'desc'          => "",
				'subtitle'      => "",
				'default'       => '#222222',
				'validate'      => 'color',
			),
            array(
				'id'            => 'social-info-services',
				'type'          => 'info',
                'class'         => 'to-accordion',
				'desc'          => __be( 'Social services' ),
                'icon'          => '',
			),
            array(
				'id'            => 'social-500px',
				'type'          => 'text',
				'title'         => __be( '500px' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-500px',
			),
            array(
				'id'            => 'social-aim',
				'type'          => 'text',
				'title'         => __be( 'Aim' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-aim',
			),
            array(
				'id'            => 'social-behance',
				'type'          => 'text',
				'title'         => __be( 'Behance' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-behance',
			),
            array(
				'id'            => 'social-blogger',
				'type'          => 'text',
				'title'         => __be( 'Blogger' ),
                "default"       => '#',
                'class'          => 'social_icon a13_soc-blogger',
			),
            array(
				'id'            => 'social-delicious',
				'type'          => 'text',
				'title'         => __be( 'Delicious' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-delicious',
			),
            array(
				'id'            => 'social-deviantart',
				'type'          => 'text',
				'title'         => __be( 'Deviantart' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-deviantart',
			),
            array(
				'id'            => 'social-digg',
				'type'          => 'text',
				'title'         => __be( 'Digg' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-digg',
			),
            array(
				'id'            => 'social-dribbble',
				'type'          => 'text',
				'title'         => __be( 'Dribbble' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-dribbble',
			),
            array(
				'id'            => 'social-facebook',
				'type'          => 'text',
				'title'         => __be( 'Facebook' ),
                "default"       => '#',
                'class'          => 'social_icon a13_soc-facebook',
			),
            array(
				'id'            => 'social-flickr',
				'type'          => 'text',
				'title'         => __be( 'Flickr' ),
                "default"       => '#',
                'class'          => 'social_icon a13_soc-flickr',
			),
            array(
				'id'            => 'social-forrst',
				'type'          => 'text',
				'title'         => __be( 'Forrst' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-forrst',
			),
            array(
				'id'            => 'social-foursquare',
				'type'          => 'text',
				'title'         => __be( 'Foursquare' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-foursquare',
			),
            array(
				'id'            => 'social-github',
				'type'          => 'text',
				'title'         => __be( 'Github' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-github',
			),
            array(
				'id'            => 'social-googleplus',
				'type'          => 'text',
				'title'         => __be( 'Google Plus' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-googleplus',
			),
            array(
				'id'            => 'social-instagram',
				'type'          => 'text',
				'title'         => __be( 'Instagram' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-instagram',
			),
            array(
				'id'            => 'social-lastfm',
				'type'          => 'text',
				'title'         => __be( 'Lastfm' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-lastfm',
			),
            array(
				'id'            => 'social-linkedin',
				'type'          => 'text',
				'title'         => __be( 'Linkedin' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-linkedin',
			),
            array(
				'id'            => 'social-mailto',
				'type'          => 'text',
				'title'         => __be( 'Mailto' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-mailto',
			),
            array(
				'id'            => 'social-paypal',
				'type'          => 'text',
				'title'         => __be( 'Paypal' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-paypal',
			),
            array(
				'id'            => 'social-pinterest',
				'type'          => 'text',
				'title'         => __be( 'Pinterest' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-pinterest',
			),
            array(
				'id'            => 'social-quora',
				'type'          => 'text',
				'title'         => __be( 'Quora' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-quora',
			),
            array(
				'id'            => 'social-rss',
				'type'          => 'text',
				'title'         => __be( 'RSS' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-rss',
			),
            array(
				'id'            => 'social-reddit',
				'type'          => 'text',
				'title'         => __be( 'Reddit' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-reddit',
			),
            array(
				'id'            => 'social-sharethis',
				'type'          => 'text',
				'title'         => __be( 'Sharethis' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-sharethis',
			),
            array(
				'id'            => 'social-skype',
				'type'          => 'text',
				'title'         => __be( 'Skype' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-skype',
			),
            array(
				'id'            => 'social-spotify',
				'type'          => 'text',
				'title'         => __be( 'Spotify' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-spotify',
			),
            array(
				'id'            => 'social-stumbleupon',
				'type'          => 'text',
				'title'         => __be( 'Stumbleupon' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-stumbleupon',
			),
            array(
				'id'            => 'social-tumblr',
				'type'          => 'text',
				'title'         => __be( 'Tumblr' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-tumblr',
			),
            array(
				'id'            => 'social-twitter',
				'type'          => 'text',
				'title'         => __be( 'Twitter' ),
                "default"       => '#',
                'class'          => 'social_icon a13_soc-twitter',
			),
            array(
				'id'            => 'social-vimeo',
				'type'          => 'text',
				'title'         => __be( 'Vimeo' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-vimeo',
			),
            array(
				'id'            => 'social-wordpress',
				'type'          => 'text',
				'title'         => __be( 'Wordpress' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-wordpress',
			),
            array(
				'id'            => 'social-yahoo',
				'type'          => 'text',
				'title'         => __be( 'Yahoo' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-yahoo',
			),
            array(
				'id'            => 'social-yelp',
				'type'          => 'text',
				'title'         => __be( 'Yelp' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-yelp',
			),
            array(
				'id'            => 'social-youtube',
				'type'          => 'text',
				'title'         => __be( 'Youtube' ),
                "default"       => '',
                'class'          => 'social_icon a13_soc-youtube',
			),
            
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( '404 page' ),
		'icon' => 'el-icon-home',
        'fields' => array(
            array(
				'id'            => '404_custom_page',
				'type'          => 'select',
				'data'          => 'pages',
                'placeholder'   => __be( 'Select page' ), 
				'title'         => __be( 'Page to be displayed as 404 error page.' ),
				'subtitle'      => "",
				'desc'          => '',
			),
            
        ),
    ) );
    Redux::setSection( $opt_name, array(
        'title' => __be( 'Custom Style' ),
		'icon' => 'el-icon-home',
        'fields' => array(
            array(
				'id'            => 'theme_custom_css',
				'type'          => 'textarea', 
				'title'         => __be( 'Valid css text' ),
                "default"       => '',
                'desc'          => "",
				'subtitle'      => "",
			),
            
        ),
    ) );
    
    


    if ( file_exists( dirname( __FILE__ ) . '/../README.md' ) ) {
        $section = array(
            'icon'   => 'el el-list-alt',
            'title'  => __( 'Documentation', 'redux-framework-demo' ),
            'fields' => array(
                array(
                    'id'       => '17',
                    'type'     => 'raw',
                    'markdown' => true,
                    'content'  => file_get_contents( dirname( __FILE__ ) . '/../README.md' )
                ),
            ),
        );
        Redux::setSection( $opt_name, $section );
    }
    /*
     * <--- END SECTIONS
     */

    /**
     * This is a test function that will let you see when the compiler hook occurs.
     * It only runs if a field    set with compiler=>true is changed.
     * */
    function compiler_action( $options, $css, $changed_values ) {
        echo '<h1>The compiler hook has run!</h1>';
        echo "<pre>";
        print_r( $changed_values ); // Values that have changed since the last save
        echo "</pre>";
        //print_r($options); //Option values
        //print_r($css); // Compiler selector CSS values  compiler => array( CSS SELECTORS )
    }

    /**
     * Custom function for the callback validation referenced above
     * */
    if ( ! function_exists( 'redux_validate_callback_function' ) ) {
        function redux_validate_callback_function( $field, $value, $existing_value ) {
            $error   = false;
            $warning = false;

            //do your validation
            if ( $value == 1 ) {
                $error = true;
                $value = $existing_value;
            } elseif ( $value == 2 ) {
                $warning = true;
                $value   = $existing_value;
            }

            $return['value'] = $value;

            if ( $error == true ) {
                $return['error'] = $field;
                $field['msg']    = 'your custom error message';
            }

            if ( $warning == true ) {
                $return['warning'] = $field;
                $field['msg']      = 'your custom warning message';
            }

            return $return;
        }
    }

    /**
     * Custom function for the callback referenced above
     */
    if ( ! function_exists( 'redux_my_custom_field' ) ) {
        function redux_my_custom_field( $field, $value ) {
            print_r( $field );
            echo '<br/>';
            print_r( $value );
        }
    }

    /**
     * Custom function for filtering the sections array. Good for child themes to override or add to the sections.
     * Simply include this function in the child themes functions.php file.
     * NOTE: the defined constants for URLs, and directories will NOT be available at this point in a child theme,
     * so you must use get_template_directory_uri() if you want to use any of the built in icons
     * */
    function dynamic_section( $sections ) {
        //$sections = array();
        $sections[] = array(
            'title'  => __( 'Section via hook', 'redux-framework-demo' ),
            'desc'   => __( '<p class="description">This is a section created by adding a filter to the sections array. Can be used by child themes to add/remove sections from the options.</p>', 'redux-framework-demo' ),
            'icon'   => 'el el-paper-clip',
            // Leave this as a blank section, no options just some intro text set above.
            'fields' => array()
        );

        return $sections;
    }

    /**
     * Filter hook for filtering the args. Good for child themes to override or add to the args array. Can also be used in other functions.
     * */
    function change_arguments( $args ) {
        $args['dev_mode'] = false;

        return $args;
    }

    /**
     * Filter hook for filtering the default value of any given field. Very useful in development mode.
     * */
    function change_defaults( $defaults ) {
        $defaults['str_replace'] = 'Testing filter hook!';

        return $defaults;
    }

    // Remove the demo link and the notice of integrated demo from the redux-framework plugin
    function remove_demo() {

        // Used to hide the demo mode link from the plugin page. Only used when Redux is a plugin.
        if ( class_exists( 'ReduxFrameworkPlugin' ) ) {
            remove_filter( 'plugin_row_meta', array(
                ReduxFrameworkPlugin::instance(),
                'plugin_metalinks'
            ), null, 2 );

            // Used to hide the activation notice informing users of the demo panel. Only used when Redux is a plugin.
            remove_action( 'admin_notices', array( ReduxFrameworkPlugin::instance(), 'admin_notices' ) );
        }
    }
